---
title: <span class="badge builder"></span> Key
---
# <span class="badge builder"></span> Key

## Constructor

```python
Key()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> testdata.Key
```

### <span class="badge object-method"></span> tick

```python
def tick(tick: float) -> typing.Self
```

### <span class="badge object-method"></span> type_val

```python
def type_val(type_val: str) -> typing.Self
```

### <span class="badge object-method"></span> uid

```python
def uid(uid: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Key](./object-Key.md)
